( cd usr ; rm -rf i486-linuxaout )
( cd usr ; ln -sf ix86-linuxaout i486-linuxaout )
( cd usr/ix86-linuxaout/lib ; rm -rf libvga.so.1 )
( cd usr/ix86-linuxaout/lib ; ln -sf libvga.so.1.2.9 libvga.so.1 )
( cd lib ; rm -rf libc.so.4 )
( cd lib ; ln -sf libc.so.4.7.6 libc.so.4 )
( cd lib ; rm -rf libcurses.so.0 )
( cd lib ; ln -sf libcurses.so.0.1.2 libcurses.so.0 )
( cd lib ; rm -rf libm.so.4 )
( cd lib ; ln -sf libm.so.4.6.27 libm.so.4 )
